@@ -3,14 +3,15 @@ import asyncio
 from pathlib import Path
 
 import uvloop
+from PIL import Image
 from hypy_utils import printc, json_stringify, write
 from hypy_utils.dict_utils import remove_keys
 from pyrogram import Client
-from pyrogram.enums import MessageServiceType, MessageMediaType
 from pyrogram.file_id import FileId
 from pyrogram.types import User, Chat, Message
 
 from .config import load_config, Config
+from .consts import HTML
 from .convert import convert_text, convert_media_dict
 from .download_media import download_media, has_media, guess_ext, download_media_urlsafe
 from .grouper import group_msgs
@@ -49,6 +50,7 @@ async def process_message(msg: Message, path: Path) -> dict:
     m = {
         "id": msg.id,
         "date": msg.date,
+        "type": 'service' if msg.service else None,
         "text": effective_text(msg),
         "author": msg.author_signature,
         "views": msg.views,
@@ -61,13 +63,11 @@ async def process_message(msg: Message, path: Path) -> dict:
         "reply_id": msg.reply_to_message_id,
         "file": convert_media_dict(msg)
     }
-    st = 'service' if msg.service else None
-    m['type'] = st or (m.get('file') or {}).get('media_type')
 
     # Download file
+    f = m.get('file')
     if has_media(msg):
         fp, name = await download_media_urlsafe(app, msg, directory=media_path)
-        f = m['file']
         f['original_name'] = name
 
         # Convert tgs sticker
@@ -86,9 +86,12 @@ async def process_message(msg: Message, path: Path) -> dict:
             del f['thumbs']
 
     # Move photo to its own key
-    if m['file']:
-        if m['type'] == 'photo' or (not m['type'] and (m['file'].get('mime_type') or "").startswith("image")):
-            m['image'] = m.pop('file')
+    if f:
+        if f['media_type'] == 'photo' or (not f['media_type'] and (m['file'].get('mime_type') or "").startswith("image")):
+            img = m['image'] = m.pop('file')
+
+            # Read image size
+            img['width'], img['height'] = Image.open(path / img['url']).size
 
     return remove_keys(remove_nones(m), {'file_id', 'file_unique_id'})
 
@@ -120,6 +123,9 @@ async def process_chat(chat_id: int, path: Path):
     results = group_msgs(results)
 
     write(path / "posts.json", json_stringify(results, indent=2))
+    write(path / "index.html", HTML)
+
+    printc(f"&aDone! Saved to {path / 'posts.json'}")
 
 
 async def run_app():
